﻿using C1.FlexMap;
using C1Map.Sources;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace C1Map_CustomSources
{
    public partial class Form1 : Form
    {
        Dictionary<string,ITileSource> _customSources;
        ITileSource _currentSource;
        string tilesLocation = @"..\..\Tiles\";
        public Form1()
        {
            InitializeComponent();
            InitSources();
        }

        private void InitSources()
        {
            _customSources = new Dictionary<string,ITileSource>();
            _customSources.Add("OpenStreet-online",new OpenStreetTileSource());
            _customSources.Add("Stamen-Toner", new StamenTonerTileSource());
            _customSources.Add("Stamen-Terrain", new StamenTerrainTileSource());
            _customSources.Add("Stamen-WaterColor", new StamenWaterColorTileSource());
            _customSources.Add("OpenStreet-offline", new OfflineTilesSource(tilesLocation));



            _currentSource = _customSources.Values.First();
            UpdateSource();

            cmbTileSources.DataSource = new BindingSource(_customSources, null);
            cmbTileSources.DisplayMember = "Key";
            cmbTileSources.ValueMember = "Value";
            cmbTileSources.SelectionChangeCommitted += CmbTileSources_SelectionChangeCommitted;
        }

        private void CmbTileSources_SelectionChangeCommitted(object sender, EventArgs e)
        {
            _currentSource = (ITileSource)cmbTileSources.SelectedValue;
            UpdateSource();
        }

        private void UpdateSource()
        {
            c1Map1.TileLayer.TileSource = _currentSource;
            var attributedSource = _currentSource as IRequireAttribution;
            if (attributedSource != null)
            {
                lblAttribution.Text = attributedSource.Attribution;
                lblAttribution.Visible = true;
            }
            else {
                lblAttribution.Text = string.Empty;
                lblAttribution.Visible = false;
            }
        }
    }
}
